@@ -126,6 +126,11 @@ with open( os.path.join(current_dir, 'sources/CharPinyin.p'), 'rb') as handle:
     CharPinyinInfos = pickle.load(handle)
 
 
+## phonemes
+with open( os.path.join(current_dir, 'sources/WordPhoneme.p'), 'rb') as handle:
+    WordPhenomeInfo = pickle.load(handle)
+
+
 def subcompGrainChar(char, end_grain = False):
     '''char level only!'''
     if char in CharSubCompInfos:
@@ -227,9 +232,6 @@ def syllableGrainToken(token, end_grain = False):
         info = ['']
     return info
 
-## phonemes
-with open('nlptext/sources/WordPhoneme.p', 'rb') as handle:
-    WordPhenomeInfo = pickle.load(handle)
 
 def phonemeGrainToken(token, end_grain = False): 
     try:
